@@ -201,12 +201,15 @@ def Barati_high(Re):
     '''
     Re2 = Re*Re
     t0 = 1.0/Re
-    t1 = (Re/6530.)
-    t2 = (Re/1620.)
+    t1 = Re*(1.0/6530.)
+    t2 = Re*(1.0/1620)
     t3 = log10(Re2 + 10.7563)
+    t4 = 1.0/(Re+Re2)
+    t4 *= t4
+    t4 *= t4
     tanhRe = tanh(Re)
     Cd = (8E-6*(t1*t1 + tanhRe - 8.0*log10(Re))
-    - 0.4119*exp(-2.08E43/(Re+Re2)**4)
+    - 0.4119*exp(-2.08E43*t4)
     - 2.1344*exp(-t0*(t3*t3 + 9.9867))
     + 0.1357*exp(-t0*(t2*t2 + 10370.))
     - 8.5E-3*t0*(2.0*log10(tanh(tanhRe)) - 2825.7162) + 2.4795)
@@ -1345,7 +1348,7 @@ def v_terminal(D, rhop, rho, mu, Method=None):
 
     # Begin the solver with 1/100 th the velocity possible at the maximum
     # Reynolds number the correlation is good for
-    return secant(_v_terminal_err, V_max/100, xtol=1E-12, args=(Method, Re_almost, main))
+    return secant(_v_terminal_err, V_max*1e-2, xtol=1E-12, args=(Method, Re_almost, main))
 
 
 def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
